.. _user:

#####################
User Reference Manual
#####################

:Release: |version|
:Date: |today|

This guide provides details on all public functions, modules and classes 
included in Py-ART which a typical user will use on a regular basis.

For a more detailed listing of all functions, module and classes (both public
and private) aimed at developers please see the :ref:`developer`.

.. toctree::
    :maxdepth: 1

    core
    io
    aux_io
    correct
    retrieve
    graph
    map
    testing

Packages level functions:

.. currentmodule:: pyart
.. autosummary::
    :toctree: generated/

    load_config
    test
